#!/usr/bin/perl -w
#@PERL@ -w

use strict;
use POSIX qw(getcwd);
require 'common.pm';

#use Cwd;

#
# vars

our (%set, %conf);

#
# test configuration

for (;;) {
	$_ = $ARGV[0];
	last unless defined($_) and /^-/;

	if (/^--long$/) {
		shift @ARGV;
		$set{'long'}++;
	} elsif (/^--leak$/) {
		shift @ARGV;
		$set{'leak'}++;
	} elsif (/^-h$|^--help$/) {
		print "$0: [-leak] [-long] [test1 test2 ...]\n";
		exit 0;
	} else {
		print "unknown argument: $_\n";
		exit 3;
	}
}


$set{'debug'} = 2;
$set{'path'} = getcwd();
$set{'bin'} = "$set{path}/../src/smtp-gated";
$set{'wrapper'} = $set{'leak'} ? "valgrind --leak-check=full" : "";
i_read_defs();

$set{'path_log'} = "$set{path}/log";
$set{'log'} = "$set{path_log}/test.log";

$set{'src_ip'} = '127.0.0.1';
$set{'src_ip_alt'} = '127.0.0.2';
$set{'test_port'} = 2110;

$set{'ip_mta'} = $set{'src_ip'};
$set{'mta_port'} = $set{'test_port'} + 1;
$set{'ip_clamd'} = $set{'ip_mta'};
$set{'port_clamd'} = $set{'test_port'} + 2;
$set{'ip_spamd'} = $set{'ip_mta'};
$set{'port_spamd'} = $set{'test_port'} + 3;

$set{'timeout'} = 5;
$set{'flush_timeout'} = 1;
$set{'process_timeout'} = $set{'leak'} ? 15 : 3;
$set{'close_delay'} = 0.0;

$set{'args'} = '-D 0x03';
$set{'conf'} = "$set{path}/log/test.conf";
#$set{'redir'} = "1>$set{log} 2>$set{log}";
$set{'redir'} = '';



#
# daemon default configuration

$conf{'pidfile'} = "$set{path}/test.pid";
$conf{'statefile'} = "$set{path_log}/state";
$conf{'spool_path'} = "$set{path}/msg";
$conf{'lock_path'} = "$set{path}/lock";
$conf{'proxy_name'} = 'proxy.auto.test';
$conf{'bind_address'} = $set{'ip_mta'};
$conf{'port'} = $set{'mta_port'} + 10;
$conf{'fixed_server'} = $set{'ip_mta'};
$conf{'fixed_server_port'} = $set{'mta_port'};
$conf{'mode'} = 'fixed';
$conf{'antivirus_path'} = "$set{ip_clamd}:$set{port_clamd}";
$conf{'antispam_path'} = "$set{ip_spamd}:$set{port_spamd}";
$conf{'antivirus_type'} = 'clamd';
$conf{'antispam_type'} = 'spamassassin';
$conf{'lock_on'} = 'never';
$conf{'log_level'} = 7;
$conf{'max_connections'} = 8;
$conf{'max_per_host'} = 4;
$conf{'max_load'} = 100;
$conf{'spam_max_load'} = 100;
$conf{'ignore_errors'} = 0;
$conf{'spam_max_size'} = 0;
$conf{'nat_header_type'} = 'none';

$set{'lock'} = "$conf{lock_path}/$set{src_ip}";

#
# setup

i_init_conf();
i_init_dirs();
i_init_signals();


#
# find tests


my @tests;
if (@ARGV == 0) {
	opendir(DIR, ".") || die "can't open '.' directory: $!\n";
	@tests = sort grep { /^[0-8]\d{2}.*\.t$/o } readdir(DIR);
	closedir(DIR);
} else {
	@tests = @ARGV;
}

print '=' x 54,"\n";
printf "%16s found: %s test(s)\n", "", scalar @tests;
print '=' x 54,"\n";

#
# run tests

$| = 1;
open(STDERR, '>'.$set{log}) || die "can't redirect STDERR to $set{log}: $!\n";
$| = 1;
print STDERR "*** $0 pid $$\n";
print STDERR "*** ".scalar localtime()."\n\n\n";
unlink($conf{'pidfile'});

# autoflush
#select(STDOUT); $| = 1;
#select(STDERR); $| = 1;
eval {
	require BSD::Resource;
	import BSD::Resource;
	eval "setrlimit(RLIMIT_CORE, 50000, 50000)";
};

i_run(@tests);

